@@ -1,4 +1,4 @@
-#   Copyright (C) 2006-2010 Ludovic Rousseau (ludovic.rousseau@free.fr)
+#   Copyright (C) 2006-2012 Ludovic Rousseau (ludovic.rousseau@free.fr)
 #   Copyright (C) 2010 Giuseppe Amato (additions to original interface)
 #
 # This file is free software; you can redistribute it and/or modify it
@@ -15,7 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 
-# $Id: __init__.py 227 2010-12-03 08:49:13Z lrousseau $
+# $Id: __init__.py 242 2012-04-21 06:49:12Z lrousseau $
 
 import PyKCS11.LowLevel
 import os
@@ -695,7 +695,7 @@ class Session(object):
         """
         C_Login
 
-        @param pin: the user's PIN
+        @param pin: the user's PIN or None for CKF_PROTECTED_AUTHENTICATION_PATH
         @type pin: string
         @param user_type: the user type. The default value is
         CKU_USER. You may also use CKU_SO
@@ -731,7 +731,21 @@ class Session(object):
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
 
+    def createObject(self, template):
+        """
+        C_CreateObject
+        """
+        attrs = self._template2ckattrlist(template)
+        handle = PyKCS11.LowLevel.CK_OBJECT_HANDLE()
+        rv = self.lib.C_CreateObject(self.session, attrs, handle)
+        if rv != PyKCS11.CKR_OK:
+            raise PyKCS11.PyKCS11Error(rv)
+        return handle
+
     def destroyObject(self, obj):
+        """
+        C_DestroyObject
+        """
         rv = self.lib.C_DestroyObject(self.session, obj)
         if rv != CKR_OK:
             raise PyKCS11Error(rv)
@@ -851,6 +865,12 @@ class Session(object):
         return decrypted
 
     def isNum(self, type):
+        """
+        is the type a numerical value?
+
+        @param type: PKCS#11 type like CKA_CERTIFICATE_TYPE
+        @rtype: bool
+        """
         if type in (CKA_CERTIFICATE_TYPE,
             CKA_CLASS,
             CKA_KEY_GEN_MECHANISM,
@@ -862,15 +882,28 @@ class Session(object):
         return False
 
     def isString(self, type):
+        """
+        is the type a string value?
+
+        @param type: PKCS#11 type like CKA_LABEL
+        @rtype: bool
+        """
         if type in (CKA_LABEL,
             CKA_APPLICATION):
             return True
         return False
 
     def isBool(self, type):
+        """
+        is the type a boolean value?
+
+        @param type: PKCS#11 type like CKA_ALWAYS_SENSITIVE
+        @rtype: bool
+        """
         if type in (CKA_ALWAYS_SENSITIVE,
             CKA_DECRYPT,
             CKA_ENCRYPT,
+            CKA_EXTRACTABLE,
             CKA_HAS_RESET,
             CKA_LOCAL,
             CKA_MODIFIABLE,
@@ -891,6 +924,12 @@ class Session(object):
         return False
 
     def isBin(self, type):
+        """
+        is the type a byte array value?
+
+        @param type: PKCS#11 type like CKA_MODULUS
+        @rtype: bool
+        """
         return (not self.isBool(type)) and (not self.isString(type)) and (not self.isNum(type))
 
     def _template2ckattrlist(self, template):
@@ -909,7 +948,8 @@ class Session(object):
                 if isinstance(attr[1], int):
                     attrStr = str(attr[1])
                 if isinstance(attr[1], str):
-                    attrBin = ckbytelist(len(attrStr))
+                    attrBin = ckbytelist()
+                    attrBin.reserve(len(attrStr))
                     for c in xrange(len(attrStr)):
                         attrBin.append(ord(attrStr[c]))
                 t[x].SetBin(attr[0], attrBin)
@@ -918,6 +958,15 @@ class Session(object):
         return t
 
     def generateKeyPair(self, templatePub, templatePriv, mecha=MechanismRSAGENERATEKEYPAIR):
+        """
+        generate a key pair
+
+        @param templatePub: template for the public key
+        @param templatePriv:  template for the private key
+        @param mecha: mechanism to use
+        @return: a tuple of handles (pub, priv)
+        @rtype: tuple
+        """
         tPub = self._template2ckattrlist(templatePub)
         tPriv = self._template2ckattrlist(templatePriv)
         ck_pub_handle = PyKCS11.LowLevel.CK_OBJECT_HANDLE()
